@@ -2,33 +2,14 @@
  * (C) Copyright 2002
  * Wolfgang Denk, DENX Software Engineering, wd@denx.de.
  *
- * See file CREDITS for list of people who contributed to this
- * project.
- *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of
- * the License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston,
- * MA 02111-1307 USA
- *
- * Be sure to mark tests to be run before relocation as such with the
- * CFG_POST_PREREL flag so that logging is done correctly if the
- * logbuffer support is enabled.
+ * SPDX-License-Identifier:	GPL-2.0+
  */
 
 #include <common.h>
 
 #include <post.h>
 
+extern int ocm_post_test (int flags);
 extern int cache_post_test (int flags);
 extern int watchdog_post_test (int flags);
 extern int i2c_post_test (int flags);
@@ -45,6 +26,7 @@ extern int sysmon_post_test (int flags);
 extern int dsp_post_test (int flags);
 extern int codec_post_test (int flags);
 extern int ecc_post_test (int flags);
+extern int flash_post_test(int flags);
 
 extern int dspic_init_post_test (int flags);
 extern int dspic_post_test (int flags);
@@ -52,6 +34,10 @@ extern int gdc_post_test (int flags);
 extern int fpga_post_test (int flags);
 extern int lwmon5_watchdog_post_test(int flags);
 extern int sysmon1_post_test(int flags);
+extern int coprocessor_post_test(int flags);
+extern int led_post_test(int flags);
+extern int button_post_test(int flags);
+extern int memory_regions_post_test(int flags);
 
 extern int sysmon_init_f (void);
 
@@ -60,7 +46,19 @@ extern void sysmon_reloc (void);
 
 struct post_test post_list[] =
 {
-#if CONFIG_POST & CFG_POST_CACHE
+#if CONFIG_POST & CONFIG_SYS_POST_OCM
+    {
+	"OCM test",
+	"ocm",
+	"This test checks on chip memory (OCM).",
+	POST_ROM | POST_ALWAYS | POST_PREREL | POST_CRITICAL | POST_STOP,
+	&ocm_post_test,
+	NULL,
+	NULL,
+	CONFIG_SYS_POST_OCM
+    },
+#endif
+#if CONFIG_POST & CONFIG_SYS_POST_CACHE
     {
 	"Cache test",
 	"cache",
@@ -69,10 +67,10 @@ struct post_test post_list[] =
 	&cache_post_test,
 	NULL,
 	NULL,
-	CFG_POST_CACHE
+	CONFIG_SYS_POST_CACHE
     },
 #endif
-#if CONFIG_POST & CFG_POST_WATCHDOG
+#if CONFIG_POST & CONFIG_SYS_POST_WATCHDOG
 #if defined(CONFIG_POST_WATCHDOG)
 	CONFIG_POST_WATCHDOG,
 #else
@@ -84,11 +82,11 @@ struct post_test post_list[] =
 	&watchdog_post_test,
 	NULL,
 	NULL,
-	CFG_POST_WATCHDOG
+	CONFIG_SYS_POST_WATCHDOG
     },
 #endif
 #endif
-#if CONFIG_POST & CFG_POST_I2C
+#if CONFIG_POST & CONFIG_SYS_POST_I2C
     {
 	"I2C test",
 	"i2c",
@@ -97,10 +95,10 @@ struct post_test post_list[] =
 	&i2c_post_test,
 	NULL,
 	NULL,
-	CFG_POST_I2C
+	CONFIG_SYS_POST_I2C
     },
 #endif
-#if CONFIG_POST & CFG_POST_RTC
+#if CONFIG_POST & CONFIG_SYS_POST_RTC
     {
 	"RTC test",
 	"rtc",
@@ -109,10 +107,10 @@ struct post_test post_list[] =
 	&rtc_post_test,
 	NULL,
 	NULL,
-	CFG_POST_RTC
+	CONFIG_SYS_POST_RTC
     },
 #endif
-#if CONFIG_POST & CFG_POST_MEMORY
+#if CONFIG_POST & CONFIG_SYS_POST_MEMORY
     {
 	"Memory test",
 	"memory",
@@ -121,10 +119,10 @@ struct post_test post_list[] =
 	&memory_post_test,
 	NULL,
 	NULL,
-	CFG_POST_MEMORY
+	CONFIG_SYS_POST_MEMORY
     },
 #endif
-#if CONFIG_POST & CFG_POST_CPU
+#if CONFIG_POST & CONFIG_SYS_POST_CPU
     {
 	"CPU test",
 	"cpu",
@@ -134,10 +132,10 @@ struct post_test post_list[] =
 	&cpu_post_test,
 	NULL,
 	NULL,
-	CFG_POST_CPU
+	CONFIG_SYS_POST_CPU
     },
 #endif
-#if CONFIG_POST & CFG_POST_FPU
+#if CONFIG_POST & CONFIG_SYS_POST_FPU
     {
 	"FPU test",
 	"fpu",
@@ -147,10 +145,13 @@ struct post_test post_list[] =
 	&fpu_post_test,
 	NULL,
 	NULL,
-	CFG_POST_FPU
+	CONFIG_SYS_POST_FPU
     },
 #endif
-#if CONFIG_POST & CFG_POST_UART
+#if CONFIG_POST & CONFIG_SYS_POST_UART
+#if defined(CONFIG_POST_UART)
+	CONFIG_POST_UART,
+#else
     {
 	"UART test",
 	"uart",
@@ -159,46 +160,35 @@ struct post_test post_list[] =
 	&uart_post_test,
 	NULL,
 	NULL,
-	CFG_POST_UART
+	CONFIG_SYS_POST_UART
     },
+#endif /* CONFIG_POST_UART */
 #endif
-#if CONFIG_POST & CFG_POST_ETHER
+#if CONFIG_POST & CONFIG_SYS_POST_ETHER
     {
 	"ETHERNET test",
 	"ethernet",
 	"This test verifies the ETHERNET operation.",
-	POST_RAM | POST_ALWAYS | POST_MANUAL,
+	POST_RAM | POST_ALWAYS,
 	&ether_post_test,
 	NULL,
 	NULL,
-	CFG_POST_ETHER
+	CONFIG_SYS_POST_ETHER
     },
 #endif
-#if CONFIG_POST & CFG_POST_SPI
-    {
-	"SPI test",
-	"spi",
-	"This test verifies the SPI operation.",
-	POST_RAM | POST_ALWAYS | POST_MANUAL,
-	&spi_post_test,
-	NULL,
-	NULL,
-	CFG_POST_SPI
-    },
-#endif
-#if CONFIG_POST & CFG_POST_USB
+#if CONFIG_POST & CONFIG_SYS_POST_USB
     {
 	"USB test",
 	"usb",
 	"This test verifies the USB operation.",
-	POST_RAM | POST_ALWAYS | POST_MANUAL,
+	POST_RAM | POST_ALWAYS,
 	&usb_post_test,
 	NULL,
 	NULL,
-	CFG_POST_USB
+	CONFIG_SYS_POST_USB
     },
 #endif
-#if CONFIG_POST & CFG_POST_SPR
+#if CONFIG_POST & CONFIG_SYS_POST_SPR
     {
 	"SPR test",
 	"spr",
@@ -207,10 +197,10 @@ struct post_test post_list[] =
 	&spr_post_test,
 	NULL,
 	NULL,
-	CFG_POST_SPR
+	CONFIG_SYS_POST_SPR
     },
 #endif
-#if CONFIG_POST & CFG_POST_SYSMON
+#if CONFIG_POST & CONFIG_SYS_POST_SYSMON
     {
 	"SYSMON test",
 	"sysmon",
@@ -219,22 +209,22 @@ struct post_test post_list[] =
 	&sysmon_post_test,
 	&sysmon_init_f,
 	&sysmon_reloc,
-	CFG_POST_SYSMON
+	CONFIG_SYS_POST_SYSMON
     },
 #endif
-#if CONFIG_POST & CFG_POST_DSP
+#if CONFIG_POST & CONFIG_SYS_POST_DSP
     {
 	"DSP test",
 	"dsp",
 	"This test checks any connected DSP(s).",
-	POST_RAM | POST_MANUAL,
+	POST_RAM | POST_ALWAYS,
 	&dsp_post_test,
 	NULL,
 	NULL,
-	CFG_POST_DSP
+	CONFIG_SYS_POST_DSP
     },
 #endif
-#if CONFIG_POST & CFG_POST_CODEC
+#if CONFIG_POST & CONFIG_SYS_POST_CODEC
     {
 	"CODEC test",
 	"codec",
@@ -243,10 +233,10 @@ struct post_test post_list[] =
 	&codec_post_test,
 	NULL,
 	NULL,
-	CFG_POST_CODEC
+	CONFIG_SYS_POST_CODEC
     },
 #endif
-#if CONFIG_POST & CFG_POST_ECC
+#if CONFIG_POST & CONFIG_SYS_POST_ECC
     {
 	"ECC test",
 	"ecc",
@@ -255,24 +245,60 @@ struct post_test post_list[] =
 	&ecc_post_test,
 	NULL,
 	NULL,
-	CFG_POST_ECC
+	CONFIG_SYS_POST_ECC
     },
 #endif
-#if CONFIG_POST & CFG_POST_BSPEC1
+#if CONFIG_POST & CONFIG_SYS_POST_BSPEC1
 	CONFIG_POST_BSPEC1,
 #endif
-#if CONFIG_POST & CFG_POST_BSPEC2
+#if CONFIG_POST & CONFIG_SYS_POST_BSPEC2
 	CONFIG_POST_BSPEC2,
 #endif
-#if CONFIG_POST & CFG_POST_BSPEC3
+#if CONFIG_POST & CONFIG_SYS_POST_BSPEC3
 	CONFIG_POST_BSPEC3,
 #endif
-#if CONFIG_POST & CFG_POST_BSPEC4
+#if CONFIG_POST & CONFIG_SYS_POST_BSPEC4
 	CONFIG_POST_BSPEC4,
 #endif
-#if CONFIG_POST & CFG_POST_BSPEC4
+#if CONFIG_POST & CONFIG_SYS_POST_BSPEC5
 	CONFIG_POST_BSPEC5,
 #endif
+#if CONFIG_POST & CONFIG_SYS_POST_COPROC
+    {
+	"Coprocessors communication test",
+	"coproc_com",
+	"This test checks communication with coprocessors.",
+	POST_RAM | POST_ALWAYS | POST_CRITICAL,
+	&coprocessor_post_test,
+	NULL,
+	NULL,
+	CONFIG_SYS_POST_COPROC
+    },
+#endif
+#if CONFIG_POST & CONFIG_SYS_POST_FLASH
+    {
+	"Parallel NOR flash test",
+	"flash",
+	"This test verifies parallel flash operations.",
+	POST_RAM | POST_SLOWTEST | POST_MANUAL,
+	&flash_post_test,
+	NULL,
+	NULL,
+	CONFIG_SYS_POST_FLASH
+    },
+#endif
+#if CONFIG_POST & CONFIG_SYS_POST_MEM_REGIONS
+    {
+	"Memory regions test",
+	"mem_regions",
+	"This test checks regularly placed regions of the RAM.",
+	POST_ROM | POST_SLOWTEST | POST_PREREL,
+	&memory_regions_post_test,
+	NULL,
+	NULL,
+	CONFIG_SYS_POST_MEM_REGIONS
+    },
+#endif
 };
 
-unsigned int post_list_size = sizeof (post_list) / sizeof (struct post_test);
+unsigned int post_list_size = ARRAY_SIZE(post_list);
